summaryrefslogtreecommitdiff
path: root/piglit-summary.py
diff options
context:
space:
mode:
authorDylan Baker <baker.dylan.c@gmail.com>2014-05-02 00:23:28 -0700
committerDylan Baker <baker.dylan.c@gmail.com>2014-05-06 20:10:22 -0700
commit9b1e7da290cd612690e85bcacc99b50c65d83fe6 (patch)
tree2368cf51b5639a666245636b50d42dde5bf7fd24 /piglit-summary.py
parent463b049bf3b0a9cc41bc4886d013f161b8156e74 (diff)
framework: move executable functions to modules
This moves piglit-run and piglit-resume main() functions to framework.programs.run as run() and resume() respectively, and moves piglit-summary-* to framework.programs.summary. It then creates compatibility wrappers as piglit-*.py for the functions. This is groundwork for a combined piglit interface. The original files could not be imported directly since they have dash (-) in their name, and python considers dash an illegal character for function, class, and modules names, and python would raise an ImportError when attempting to import one of them. Signed-off-by: Dylan Baker <baker.dylan.c@gmail.com> Reviewed-by: Jordan Justen <jordan.l.justen@intel.com>
Diffstat (limited to 'piglit-summary.py')
-rwxr-xr-xpiglit-summary.py93
1 files changed, 20 insertions, 73 deletions
diff --git a/piglit-summary.py b/piglit-summary.py
index fe58e400b..b49799621 100755
--- a/piglit-summary.py
+++ b/piglit-summary.py
@@ -1,81 +1,28 @@
#!/usr/bin/env python
-#
-# Permission is hereby granted, free of charge, to any person
-# obtaining a copy of this software and associated documentation
-# files (the "Software"), to deal in the Software without
-# restriction, including without limitation the rights to use,
-# copy, modify, merge, publish, distribute, sublicense, and/or
-# sell copies of the Software, and to permit persons to whom the
-# Software is furnished to do so, subject to the following
-# conditions:
-#
-# This permission notice shall be included in all copies or
-# substantial portions of the Software.
-#
-# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY
-# KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
-# WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR
-# PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHOR(S) BE
-# LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN
-# AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF
-# OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
-# DEALINGS IN THE SOFTWARE.
-# Print a very simple summary of piglit results file(s).
-# When multiple result files are specified, compare the results
-# of each test run to look for differences/regressions.
-#
-# Brian Paul
-# April 2013
+# Copyright (c) 2014 Intel Corporation
+# Permission is hereby granted, free of charge, to any person obtaining a copy
+# of this software and associated documentation files (the "Software"), to deal
+# in the Software without restriction, including without limitation the rights
+# to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
+# copies of the Software, and to permit persons to whom the Software is
+# furnished to do so, subject to the following conditions:
-import argparse
-import os.path
-import sys
-
-sys.path.append(os.path.dirname(os.path.realpath(sys.argv[0])))
-import framework.summary as summary
-from framework.core import parse_listfile
-
-
-def main():
- parser = argparse.ArgumentParser()
+# The above copyright notice and this permission notice shall be included in
+# all copies or substantial portions of the Software.
- # Set the -d and -s options as exclusive, since it's silly to call for diff
- # and then call for only summary
- excGroup1 = parser.add_mutually_exclusive_group()
- excGroup1.add_argument("-d", "--diff",
- action="store_true",
- help="Only display the differences between multiple "
- "result files")
- excGroup1.add_argument("-s", "--summary",
- action="store_true",
- help="Only display the summary, not the individual "
- "test results")
- parser.add_argument("-l", "--list",
- action="store",
- help="Use test results from a list file")
- parser.add_argument("results",
- metavar="<Results Path(s)>",
- nargs="+",
- help="Space seperated paths to at least one results "
- "file")
- args = parser.parse_args()
+# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
+# AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
+# OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
+# SOFTWARE.
- # Throw an error if -d/--diff is called, but only one results file is
- # provided
- if args.diff and len(args.results) < 2:
- parser.error('-d/--diff cannot be specified unless two or more '
- 'results files are specified')
-
- # make list of results
- if args.list:
- args.results.extend(parse_listfile(args.list))
-
- # Generate the output
- output = summary.Summary(args.results)
- output.generate_text(args.diff, args.summary)
+""" Deprecated compatability wrapper for console summary """
+import sys
+from framework.programs.summary import console
-if __name__ == "__main__":
- main()
+console(sys.argv)